@@ -72,7 +72,8 @@ Classes & Functions
 import requests
 import numpy as np
 
-from .proplist import prop2key, prop2abr, abr2prop
+from .proplist import prop2abr, abr2prop
+from .proplist import *
 from .version import __version__
 
 __license__   = "MIT"
